pub fn send<T: Serialize>(obj: &T)Expand description
Send a serializable object down the pipe to the parent process. Panics if:
- Unable to get a lock on the PIPE_WRITER.
- The pipe module has not first been initialised with
pipe::init. - The implementation of Serialize panics.
- The writer returns an
std::io::Error.
See try_send for a version that does not panic in the event of a serialisation or io::Error.