pub fn try_send<T: Serialize>(obj: &T) -> Result<(), PipeError>Expand description
Try and send a serializable object down the pipe to the parent process. Panics if:
- Unable to get a lock on the PIPE_WRITER.
- The pipe module has not first been initialised with
pipe::init.